#
# spec file for package libunicode
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ver     0
%define mayor   6
%define lname   libunicode%{ver}_%{mayor}
%define sover   %{ver}.%{mayor}
%define force_gcc_version 13
Name:           libunicode
Version:        0.6.0
Release:        1.1
Summary:        Modern C++20 Unicode library
License:        Apache-2.0
URL:            https://github.com/contour-terminal/libunicode
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  unicode-ucd >= 16.0.0
BuildRequires:  cmake(Catch2) >= 3.3.0
BuildRequires:  cmake(range-v3)
%if 0%{?suse_version} < 1600
BuildRequires:  gcc%{?force_gcc_version}
BuildRequires:  gcc%{?force_gcc_version}-c++
%endif
ExclusiveArch:  x86_64 aarch64

%description

The goal of libunicode library is to bring painless unicode support to C++ with
simple and easy to understand APIs. The API naming conventions are chosen to
look familiar to those using the C++ standard libary.

%package -n     %{lname}
Summary:        Library files for %{name}

%description -n %{lname}

The %{name} package contains libraries files for applications
that use %{name}

%package        devel
Summary:        Development files for %{name}
Requires:       %{lname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        tools
Summary:        Tools for %{name}
Requires:       %{lname} = %{version}

%description    tools
The %{name}-tools package contains tools about %{name}.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1600
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
%cmake \
	-DLIBUNICODE_UCD_DIR=%{_datadir}/unicode/ucd \
	%{nil}
%cmake_build

%install
%cmake_install

#check
#ctest

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}
%license LICENSE
%doc README.md Changelog.md
%{_libdir}/%{name}*.so.%{sover}*

%files devel
%license LICENSE
%{_includedir}/%{name}
%{_libdir}/cmake/%{name}
%{_libdir}/%{name}*.so

%files tools
%license LICENSE
%{_bindir}/unicode-query

%changelog
* Wed Jan  1 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to version 0.6.0
  * Supported Unicode version 16.0.0
  * Use std::format() API instead of fmtlib
  * Improvement for better SIMD config
* Mon Sep 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.5.0
  * Fetch dependencies if OS is not supported
  * Make usage of SIMD (SSE2) extension optional
  * fix catch2 error when using system catch2
  * Add benchmark and std::simd
  * Add CMakePresets to conveniently build and work with the
    sources
  * tablegen: Improve performance for names
  * minor build and .clang-format improvements
  * add gc and runs sub command to introspect grapheme clusters and
  * runs
  * Change width()'s return type from int to unsigned
  * Tiny fix to benchmark plus minor naming changes
  * Adds missing include to convert.h
- remove libunicode-fix-catch-in-cmake.patch: fix upstream
* Fri Aug  9 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Add conditional build for leap with force gcc version
* Wed Jul 17 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.4.0
  * Allow passing custom LIBUNICODE_UCD_DIR to cmake
  * Fix error handling of UTF-8 decoding for incomplete UTF-8
    sequences
  * Improve naming convention to be more streamlined.
  * Move scan_result.next to scan_state.next
  * Problem: Catch2 is always required
  * Update catch2 to v3
  * Allow building with older CMake < 3.18
- change Catch2-2-devel BuildRequires to cmake(Catch2)
- disable build test: failed unicode_test
- remove eb40101359cb283be0b736f6bda383243522fa91.patch: unneeded
  patch
- add libunicode-fix-catch-in-cmake.patch: to fix catch issue
* Tue Oct 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
